summaryrefslogtreecommitdiffhomepage
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/assertion/generateAssertionCredentials.ts6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/assertion/generateAssertionCredentials.ts b/src/assertion/generateAssertionCredentials.ts
index f79d901..c9f0c63 100644
--- a/src/assertion/generateAssertionCredentials.ts
+++ b/src/assertion/generateAssertionCredentials.ts
@@ -6,19 +6,19 @@ import { AssertionCredentials } from '@types';
* Prepare credentials for user registration via navigator.credentials.get(...)
*
* @param challenge Random string the authenticator needs to sign and pass back
* @param credentialIDs Array of base64-encoded authenticator IDs registered by the user for
* assertion
* @param timeout How long (in ms) the user can take to complete attestation
*/
export default function generateAssertionCredentials(
challenge: string,
- credentialIDs: string[],
+ base64CredentialIDs: string[],
timeout: number = 60000,
): AssertionCredentials {
return {
publicKey: {
challenge: Uint8Array.from(challenge, c => c.charCodeAt(0)),
- allowCredentials: credentialIDs.map(id => ({
+ allowCredentials: base64CredentialIDs.map(id => ({
id: base64url.toBuffer(id),
type: 'public-key',
transports: ['usb', 'ble', 'nfc'],
@@ -6,19 +6,19 @@ import { AssertionCredentials } from '@types';
*
* @param challenge Random string the authenticator needs to sign and pass back
- * @param credentialIDs Array of base64-encoded authenticator IDs registered by the user for
+ * @param base64CredentialIDs Array of base64-encoded authenticator IDs registered by the user for
* assertion
* @param timeout How long (in ms) the user can take to complete attestation